"""
iOS App Publishing Module
Handles building and publishing iOS apps using Capacitor and App Store Connect API
"""

def publish_ios(app_path):

    print("""
    TODO: 
        - Capacitor build for iOS
        - Upload to AppstoreConnect

    """)

    print("=======================================")
